

# Cosmoglobe Sky Model
[![Documentation Status](https://readthedocs.org/projects/cosmoglobe/badge/?version=latest)](https://cosmoglobe.readthedocs.io/en/latest/?badge=latest)
[![astropy](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat)](http://www.astropy.org/)

## Description
cosmoglobe is a python package that interfaces the Cosmoglobe Sky Model with the commander3 outputs for the purpose of producing astrophyiscal sky maps.

The documentation can be found at [https://cosmoglobe.readthedocs.io](https://cosmoglobe.readthedocs.io/en/latest/).
## Funding

This work has received funding from the European Union's Horizon 2020 research and innovation programme under grant agreements No 776282 (COMPET-4; BeyondPlanck), 772253 (ERC; bits2cosmology) and 819478 (ERC; Cosmoglobe).

<p align="center">
    <img src="./logo/LOGO_ERC-FLAG_EU_.jpg" height="200">
    <img src="./logo/horizon2020_logo.jpg" height="200">
</p>

---

## License

[GNU GPLv3](https://github.com/Cosmoglobe/Commander/blob/master/COPYING)
